summaryrefslogtreecommitdiff
path: root/libraries/base
diff options
context:
space:
mode:
authorMatthew Pickering <matthewtpickering@gmail.com>2022-02-03 17:15:05 +0000
committerMarge Bot <ben+marge-bot@smart-cactus.org>2022-02-08 05:28:42 -0500
commit38c6e301165777b88cc172aafed1b33d6f42099b (patch)
treebb97c29f4d2701c32811ae98e7ea523da0bc0a2a /libraries/base
parentbc5cbce61b57f57cadf5c25fa3e60cf34c3b98ea (diff)
downloadhaskell-38c6e301165777b88cc172aafed1b33d6f42099b.tar.gz
Fix some notes
Diffstat (limited to 'libraries/base')
-rw-r--r--libraries/base/GHC/Event/Windows.hsc2
-rw-r--r--libraries/base/GHC/List.hs4
2 files changed, 3 insertions, 3 deletions
diff --git a/libraries/base/GHC/Event/Windows.hsc b/libraries/base/GHC/Event/Windows.hsc
index 97a224fdc7..b22fa8d877 100644
--- a/libraries/base/GHC/Event/Windows.hsc
+++ b/libraries/base/GHC/Event/Windows.hsc
@@ -750,7 +750,7 @@ withOverlappedEx mgr fname h async offset startCB completionCB = do
-- otherwise the RTS will lock up until we get a result back.
-- In the threaded case it can be beneficial to spin on the haskell
-- side versus
- -- See also Note [Why use non-waiting getOverlappedResult requests.]
+ -- See also Note [Why use non-waiting getOverlappedResult requests]
res <- FFI.getOverlappedResult fhndl lpol False
status <- FFI.overlappedIOStatus lpol
case res of
diff --git a/libraries/base/GHC/List.hs b/libraries/base/GHC/List.hs
index 8dc897c73c..c3800d5d59 100644
--- a/libraries/base/GHC/List.hs
+++ b/libraries/base/GHC/List.hs
@@ -1446,7 +1446,7 @@ Note [Fusion for zipN/zipWithN]
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
We arrange that zip, zip3, etc, and zipWith, zipWit3 etc, are all
good consumers for their first (left) argument, and good producers.
-Here's how. See Note [Fusion for foldr2] for why it can't fuse its
+Here's how. See Note [Fusion for foldrN] for why it can't fuse its
second (right) list argument.
NB: Zips for larger tuples are in the List module.
@@ -1460,7 +1460,7 @@ NB: Zips for larger tuples are in the List module.
* To give this rule a chance to fire, we give zip a NOLINLINE[1]
pragma (although since zip is recursive it might not need it)
* Now the rules for foldr2 (see Note [Fusion for foldr2]) may fire,
or rules that fuse the build-produced output of zip.
* If none of these fire, rule "zipList" (active only in phase 1)
@@ -1460,7 +1460,7 @@ NB: Zips for larger tuples are in the List module.
* To give this rule a chance to fire, we give zip a NOLINLINE[1]
pragma (although since zip is recursive it might not need it)
-* Now the rules for foldr2 (see Note [Fusion for foldr2]) may fire,
+* Now the rules for foldr2 (see Note [Fusion for foldrN]) may fire,
or rules that fuse the build-produced output of zip.
* If none of these fire, rule "zipList" (active only in phase 1)